import {Component} from '@angular/core';
import {NavigationBarComponent} from '../navigation-bar/navigation-bar.component';
import {EmployeeNameAndSkillDataDTO, EmployeeResponseDTO} from "../../models/mitarbeiter";
import {EmployeeService} from "../../service/employee.service";
import {ActivatedRoute, Router} from "@angular/router";
import {Observable} from "rxjs";
import {QualificationGetDTO} from "../../models/skill";
import {SkillService} from "../../service/skill.service";

@Component({
  selector: 'app-employee-detail',
  standalone: true,
  imports: [NavigationBarComponent],
  templateUrl: './employee-detail.component.html',
  styleUrl: './employee-detail.component.css'
})
export class EmployeeDetailComponent {
  employee!: EmployeeResponseDTO;
  skillSet: string[] = [];
  currentId: number = 0;

  constructor(private employeeService: EmployeeService, private router: Router, private route: ActivatedRoute, private skillService: SkillService) {
    this.currentId = this.route.snapshot.params['id'];
    this.employeeService.getEmployeeById(this.route.snapshot.params['id']).subscribe(employee => {
      this.employee = employee;
      this.skillSet = this.employee.skillSet?.map(skill => skill.skill) || [];
    });
  }

  editEmployee(id: number) {
    this.router.navigate([`/mitarbeiterbearbeiten/${id}`]);
  }

  goToEmployeePage(){
    this.router.navigate(['mitarbeiter']);
  }

  deleteEmployee(id: number) {
    this.employeeService.deleteEmployee(id);
    this.router.navigate([`mitarbeiter`]);
  }


  protected readonly EmployeeService = EmployeeService;
}
