import { Component } from '@angular/core';
import { QualificationGetDTO } from '../../models/skill';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { SkillService } from '../../service/skill.service';
import { Router } from '@angular/router';
import { NavigationBarComponent } from '../navigation-bar/navigation-bar.component';

@Component({
  selector: 'app-qualifikationsverwaltung',
  standalone: true,
  imports: [ReactiveFormsModule, NavigationBarComponent],
  templateUrl: './qualifikationsverwaltung.component.html',
  styleUrl: './qualifikationsverwaltung.component.css'
})
export class QualifikationsverwaltungComponent {
  skills: Array<QualificationGetDTO> = [];
  public searchForm!: FormGroup;
  public errorDeletingSkill = false;

  constructor(private skillService: SkillService, private router: Router) { }

  submit() {
    const searchTerm = this.searchForm.get("search")?.value || '';

    this.skillService.getAllSkills().subscribe(skills => {
      let foundSkills: Array<QualificationGetDTO> = [];
      for (const skill of skills) {
        if (
          skill.skill.toLowerCase().includes(searchTerm.toLowerCase()) ||
          searchTerm == ''
        ) {
          foundSkills.push(skill);
        }
      }

      this.skills = foundSkills;
    });
  }

  editSkill(id: number) {
    this.router.navigate([`/qualifikationbearbeiten/${id}`]);
  }

  createSkill() {
    this.router.navigate(['/qualifikationerstellen']);
  }

  deleteSkill(id: number) {
    this.skillService.getEmployeesBySkill(id).subscribe(employees => {
      this.errorDeletingSkill = false;
      if (employees.employees.length == 0) {
        this.skillService.deleteSkill(id);
        this.skills = this.skills.filter(skill => skill.id != id);
      } else {
        this.errorDeletingSkill = true;
      }
    });
  }

  ngOnInit(): void {
    this.searchForm = new FormGroup({
      search: new FormControl(''),
    });
    this.skillService.getAllSkills().subscribe(skills => this.skills = skills);
  }
}
